@@ -7,6 +7,8 @@
 #'
 #' @param x An object of one of the summary classes for spectra.
 #' @param ... not used in current version.
+#' @param attr.simplify logical If all members share the same attribute value
+#'   return one copy instead of a data.frame, list or vector.
 #' @param n	Number of rows to show. If NULL, the default, will print all rows if
 #'   less than option \code{dplyr.print_max}. Otherwise, will print
 #'   \code{dplyr.print_min} rows.
@@ -42,7 +44,7 @@
 #'
 #' print(two_filters.spct)
 #'
-print.generic_spct <- function(x, ..., n = NULL, width = NULL)
+print.generic_spct <- function(x, ..., attr.simplify = TRUE, n = NULL, width = NULL)
 {
   # Skip checks of validity as we are only printing
   prev_state <- disable_check_spct()
@@ -59,7 +61,7 @@ print.generic_spct <- function(x, ..., n = NULL, width = NULL)
         paste(unique(signif(stepsize(x), 7)), sep = "", collapse = "-"),
         " nm \n", sep = "")
   }
-  what.measured <- getWhatMeasured(x)
+  what.measured <- getWhatMeasured(x, simplify = attr.simplify)
   if (!any(is.na(what.measured))) {
     if (!is.list(what.measured)) {
       what.measured <- list(what.measured)
@@ -74,7 +76,7 @@ print.generic_spct <- function(x, ..., n = NULL, width = NULL)
               what.measured,
               sep = "", collapse = "\n"), "\n")
   }
-  when.measured <- getWhenMeasured(x)
+  when.measured <- getWhenMeasured(x, simplify = attr.simplify)
   if (!any(is.na(when.measured))) {
     if (!is.list(when.measured)) {
       when.measured <- list(when.measured)
@@ -89,7 +91,7 @@ print.generic_spct <- function(x, ..., n = NULL, width = NULL)
               sapply(when.measured, as.character), " UTC",
               sep = "", collapse = "\n"), "\n")
   }
-  where.measured <- getWhereMeasured(x)
+  where.measured <- getWhereMeasured(x, simplify = attr.simplify)
   if (!any(is.na(where.measured))) {
     if (is.data.frame(where.measured)) {
       where.measured <- list(where.measured)
@@ -194,7 +196,12 @@ print.generic_spct <- function(x, ..., n = NULL, width = NULL)
 #'
 #' @export
 #'
-print.generic_mspct <- function(x, ..., n = NULL, width = NULL, n.members = 10)  {
+print.generic_mspct <- function(x,
+                                ...,
+                                attr.simplify = TRUE,
+                                n = NULL,
+                                width = NULL,
+                                n.members = 10)  {
   cat("Object: ", class(x)[1], " ", dplyr::dim_desc(x), "\n", sep = "")
   member.names <- names(x)
   if (length(member.names) > n.members) {
@@ -205,7 +212,7 @@ print.generic_mspct <- function(x, ..., n = NULL, width = NULL, n.members = 10)
   }
   for (name in member.names) {
     cat("--- Member:", name, "---\n")
-    print(x[[name]], n = n, width = width)
+    print(x[[name]], ..., attr.simplify = attr.simplify, n = n, width = width)
   }
   if (skipped.members > 0) {
     cat("..........................\n",
@@ -422,6 +429,7 @@ summary.generic_spct <- function(object,
   z
 }
 
+
 # Print spectral summaries ------------------------------------------------
 
 #' Print spectral summary
@@ -440,7 +448,7 @@ summary.generic_spct <- function(object,
 #' @examples
 #' print(summary(sun.spct))
 #'
-print.summary_generic_spct <- function(x, ...) {
+print.summary_generic_spct <- function(x, ..., attr.simplify = TRUE) {
   # ensure backwards compatibility with summary objects created by versions < 0.9.30
   if (!exists("orig.name", x) || is.na(x[["orig.name"]])) {
     x[["orig.name"]] <- "'unknown name'"
@@ -454,37 +462,45 @@ print.summary_generic_spct <- function(x, ...) {
       paste(signif(x[["wl.range"]], 8), sep = "", collapse = "-"), " nm, step ",
       paste(unique(signif(x[["wl.stepsize"]], 7)), sep = "", collapse = "-"),
       " nm\n", sep = "")
-  what.measured <- getWhatMeasured(x)
+  what.measured <- getWhatMeasured(x, simplify = attr.simplify)
   if (!any(is.na(what.measured))) {
-    if (!is.list(what.measured)) {
-      what.measured <- list(what.measured)
-    }
-    names <- names(what.measured)
-    if (is.null(names)) {
-      names <- "Label: "
+    if (length(what.measured) > 1) {
+      if (!is.list(what.measured)) {
+        what.measured <- list(what.measured)
+      }
+      names <- names(what.measured)
+      if (is.null(names)) {
+        names <- "Label: "
+      } else {
+        names <- paste(names, "label: ")
+      }
+      cat(paste(names,
+                what.measured,
+                sep = "", collapse = "\n"), "\n")
     } else {
-      names <- paste(names, "label: ")
+      cat("Label: ", what.measured, "\n")
     }
-    cat(paste(names,
-              what.measured,
-              sep = "", collapse = "\n"), "\n")
   }
-  when.measured <- getWhenMeasured(x)
+  when.measured <- getWhenMeasured(x, simplify = attr.simplify)
   if (!any(is.na(when.measured))) {
-    if (!is.list(when.measured)) {
-      when.measured <- list(when.measured)
-    }
-    names <- names(when.measured)
-    if (is.null(names)) {
-      names <- "Measured on "
+    if (length(when.measured) > 1) {
+      if (!is.list(when.measured)) {
+        when.measured <- list(when.measured)
+      }
+      names <- names(when.measured)
+      if (is.null(names)) {
+        names <- "Measured on "
+      } else {
+        names <- paste(names, "measured on ")
+      }
+      cat(paste(names,
+                sapply(when.measured, as.character), " UTC",
+                sep = "", collapse = "\n"), "\n")
     } else {
-      names <- paste(names, "measured on ")
+      cat("Measured on ", as.character(when.measured), " UTC\n")
     }
-    cat(paste(names,
-              sapply(when.measured, as.character), " UTC",
-              sep = "", collapse = "\n"), "\n")
   }
-  where.measured <- getWhereMeasured(x)
+  where.measured <- getWhereMeasured(x, simplify = attr.simplify)
   if (!any(is.na(where.measured))) {
     if (is.data.frame(where.measured)) {
       where.measured <- list(where.measured)
@@ -581,7 +597,7 @@ print.summary_generic_spct <- function(x, ...) {
 #' @param idx character Name of the column with the names of the members of the
 #' collection of spectra.
 #' @param which.metadata character vector Names of attributes to retrieve, or
-#'   "none" or "all". Obeyed if \code{expand = FALSE}, its default.
+#'   "none" or "all". Obeyed if \code{expand = "collection"}, its default.
 #'
 #' @export
 #'
@@ -629,13 +645,21 @@ summary.generic_mspct <- function(object,
   summary.tb[["w.length.max"]] <- sapply(object, wl_max)
   summary.tb[["colnames"]] <- unname(lapply(object, colnames))
 
-  if (length(which.metadata) != 1L || which.metadata != "none") {
-    if (length(which.metadata) == 1L && which.metadata == "all") {
-      which.metadata <- c("-", "names", "row.names", "spct.tags", "spct.version", "comment")
+  if (length(which.metadata) != 0L && which.metadata[1] != "none") {
+    if (length(which.metadata) == 1L && which.metadata[1] == "all") {
+     which.metadata <-
+       setdiff(spct_attributes(class(object)[1]),
+               c("spct.tags", "spct.version", "comment",
+                 "straylight.corrected",
+                 "slit.corrected",
+                 "QC_dark_pass",
+                 "idfactor",
+                 "spct.idx",
+                 "normalization")
+               )
     }
-    metadata.tb <- msdply(object, spct_attr2tb, which = which.metadata, idx = idx)
-    names(metadata.tb) <- gsub("spct_attr2tb_", "", names(metadata.tb))
-    summary.tb <- dplyr::left_join(summary.tb, metadata.tb, by = idx)
+    summary.tb <-
+      add_attr2tb(summary.tb, object, col.names = which.metadata)
   }
 
   z[["summary"]] <- summary.tb
@@ -655,6 +679,8 @@ summary.generic_mspct <- function(object,
 #'   which means use the width option.
 #' @param ... named arguments passed to the \code{print()} method for class
 #'   \code{"tbl_df"}.
+#' @param attr.simplify logical If all members share the same attribute value
+#'   return one copy instead of a data.frame, list or vector.
 #' @param n integer Number of member spectra for which information is printed.
 #'
 #' @seealso \code{\link[tibble]{formatting}}
@@ -666,8 +692,12 @@ summary.generic_mspct <- function(object,
 #' @examples
 #' print(summary(sun_evening.mspct))
 #'
-print.summary_generic_mspct <- function(x, width = NULL, ..., n = NULL) {
-  cat("Summary of ", x[["orig.class"]], " ", x[["orig.dim_desc"]], " object: ", x[["orig.name"]] ,"\n", sep = "")
+print.summary_generic_mspct <- function(x,
+                                        width = NULL,
+                                        ...,
+                                        n = NULL) {
+  cat("Summary of ", x[["orig.class"]], " ", x[["orig.dim_desc"]],
+      " object: ", x[["orig.name"]] ,"\n", sep = "")
   print(x[["summary"]], width = width, ..., n = n)
 }
 
@@ -707,19 +737,24 @@ print.summary_generic_mspct <- function(x, width = NULL, ..., n = NULL) {
 #' @name print.metadata
 #'
 print.instr_desc <- function(x, ...) {
-  if (is.null(x[["entrance.optics"]])) {
-    diffuser <- "unknown"
+  if (!length(x) || !is.list(x)) {
+    warning("'x' is not an instrument descriptor")
   } else {
-    diffuser <- x[["entrance.optics"]][["geometry"]]
+    if (!("entrance.optics" %in% names(x)) ||
+        all(is.na(x[["entrance.optics"]]))) {
+      diffuser <- "unknown"
+    } else {
+      diffuser <- x[["entrance.optics"]][["geometry"]]
+    }
+    cat("Data acquired with '",
+        x[["spectrometer.name"]], "' s.n. ", x[["spectrometer.sn"]],
+        "\ngrating '", x[["bench.grating"]],
+        "', slit '", x[["bench.slit"]], "'",
+        "\ndiffuser '", diffuser, "'",
+        ...,
+        sep = ""
+    )
   }
-  cat("Data acquired with '",
-      x[["spectrometer.name"]], "' s.n. ", x[["spectrometer.sn"]],
-            "\ngrating '", x[["bench.grating"]],
-            "', slit '", x[["bench.slit"]], "'",
-      "\ndiffuser '", diffuser, "'",
-      ...,
-      sep = ""
-  )
   invisible(x)
 }
 
@@ -728,15 +763,21 @@ print.instr_desc <- function(x, ...) {
 #' @export
 #'
 print.instr_settings <- function(x, ...) {
-  cat("integ. time (s): ",
-      paste(signif(as.numeric(x[["integ.time"]]) * 1e-6, digits = 3), collapse = ", "),
-      "\ntotal time (s): ",
-      paste(signif(as.numeric(x[["tot.time"]]) * 1e-6, digits = 3), collapse = ", "),
-      "\ncounts @ peak (% of max): ",
-      signif(as.numeric(x[["rel.signal"]]) * 100, digits = 3),
-      sep = "",
-      ...
-  )
+  if (!length(x) || !is.list(x)) {
+    warning("'x' is not an instrument settings record")
+  } else {
+    cat("integ. time (s): ",
+        paste(signif(as.numeric(x[["integ.time"]]) * 1e-6, digits = 3),
+              collapse = ", "),
+        "\ntotal time (s): ",
+        paste(signif(as.numeric(x[["tot.time"]]) * 1e-6, digits = 3),
+              collapse = ", "),
+        "\ncounts @ peak (% of max): ",
+        signif(as.numeric(x[["rel.signal"]]) * 100, digits = 3),
+        sep = "",
+        ...
+    )
+  }
   invisible(x)
 }
 
@@ -745,14 +786,18 @@ print.instr_settings <- function(x, ...) {
 #' @export
 #'
 print.filter_properties <- function(x, ...) {
-  cat("Rfr (/1): ",
-      paste(sprintf("%#.3f", x[["Rfr.constant"]]), collapse = " + "), ", ",
-      "thickness (mm): ",
-      paste(sprintf("%#.3g", x[["thickness"]] * 1e3), collapse = " + "), ", ",
-      "attenuation mode: ", x[["attenuation.mode"]], ".",
-       sep = "",
-      ...
-  )
+  if (!length(x) || !is.list(x)) {
+    warning("'x' is not a filter properties record")
+  } else {
+    cat("Rfr (/1): ",
+        paste(sprintf("%#.3f", x[["Rfr.constant"]]), collapse = " + "), ", ",
+        "thickness (mm): ",
+        paste(sprintf("%#.3g", x[["thickness"]] * 1e3), collapse = " + "), ", ",
+        "attenuation mode: ", x[["attenuation.mode"]], ".",
+        sep = "",
+        ...
+    )
+  }
   invisible(x)
 }
 
@@ -761,11 +806,15 @@ print.filter_properties <- function(x, ...) {
 #' @export
 #'
 print.solute_properties <- function(x, ...) {
-  cat("Name: ", x[["name"]][1], ", ",
+  if (!length(x) || !is.list(x)) {
+    warning("'x' is not a solute properties record")
+  } else {
+    cat("Name: ", x[["name"]][1], ", ",
       "Molar mass (Da): ", round(x[["mass"]], digits = 2), ", ",
       "Formula: ", x[["formula"]][1], ".",
       sep = "",
       ...
-  )
+    )
+  }
   invisible(x)
 }
